var sparqlEndpoint= location.protocol + '//' + location.hostname + ":3030/greenstone/query" ;
var collectionName = gs.cgiParams.c;

var comparisonQuery;
var hardLimit = 2000;
var defaultChartWidth = 468;
var defaultChartHeight = 200;
var currentQueries = 0;

var leftCollection = "nz-natlib-cat";
var rightCollection = "hathitrust-tab";

//Contains details about a comparison
function ComparisonQuery(){
	this.page = 1;
	this.datasetSelection = "";
	this.type = "intersection";
	this.pred_L = $('#sel_leftPredicate').val();
	this.predval_L = $('#sel_leftPredicateValue').val();
	this.refine_L = "";
	if($('#cb_leftRefineSearch').is(':checked'))
		this.refine_L = "  <" + $('#sel_leftVisualizePredicate').val();// + "> ?common";

	this.pred_R = $('#sel_rightPredicate').val();
	this.predval_R = $('#sel_rightPredicateValue').val();
	this.refine_R = "";
	if($('#cb_rightRefineSearch').is(':checked'))
		this.refine_R = "  <" + $('#sel_rightVisualizePredicate').val();// + "> ?common";
	$('#span_PageNum').text("1");	
}

function setupPage(){ 
	sgvizler_setup();
	drawSide("left",leftCollection);
	apply_functions("left",leftCollection);
	drawSide("right",rightCollection);
	apply_functions("right",rightCollection);
	apply_styles();
	populatePredicateSelector("all", "sel_comparisonPredicate");
}

//Redraw a side, given the collection name
function drawSide(side, collectionName){
	$('#span_' + side + 'Name').html(collectionName);
	drawOverview(collectionName, ("div_" + side + "Overview"));
	populatePredicateSelector(collectionName, ("sel_" + side + "Predicate"));
}

//Draw predicates available for dataset
function drawOverview(collection, container){
	var Q = new sgvizler.Query();
	Q.query(createOverviewQuery(collection))
		.endpointURL(sparqlEndpoint)
		.endpointOutputFormat("json")
		.chartFunction("google.visualization.Table")
		.draw(container);
}

//Return a query that searches for all uses of predicates in a graph
function createOverviewQuery(collection){
	var Query = "PREFIX gsdl: <http://localhost:3030/greenstone/data/>"
				+"SELECT (?p as ?Predicate) (COUNT (?s) as ?Total)WHERE\n"
			    + "{\n";
	if(collection=="all")
		Query 	+= "?s ?p ?o ";
	else
		Query 	+= "GRAPH gsdl:" + collection + "{"
				+ "	 ?s ?p ?o "
			    + "}";
	Query 	+= "}"
			+ "GROUP BY ?p "
			+ "ORDER BY DESC(?Predicate)";
	return Query;
}

function sgvizler_setup(){
	sgvizler
		.defaultEndpointOutputFormat('jsonp')
		.defaultChartWidth(defaultChartWidth)
		.defaultChartHeight(defaultChartHeight)
		.prefix('dc',  "http://purl.org/dc/elements/1.1/")
		.prefix('xsd',  "http://www.w3.org/2001/XMLSchema#")
		.prefix('gsdl', "http://localhost:3030/greenstone/data/")
}

function apply_styles(){
	$('.basicControls tbody tr td:first-child').addClass("alignRight");
	$('.refineControls tbody tr td:first-child').addClass("alignRight");
	$('.refineControls').toggle();
	$('#txt_comparisonPredicate').val("http://purl.org/dc/elements/1.1/Title");
	$('#div_resultPredicates').toggle();	
	$('#cb_showOnlyCommonObjects').attr('checked','checked');
	$('#cb_showOnlyCommonObjects').on('click', function(){
		$('#div_resultPredicates').toggle();	
	});

	$('#btn_submitComparison').on('click',function(){
		drawComparisonTable();
	});

	$('#btn_comparisonPagePrev').on('click',function(){
		if(comparisonQuery.page <= 1)
			return;
		$('#span_PageNum').text(--comparisonQuery.page)	
		drawComparisonTable();
	});

	$('#btn_comparisonPageNext').on('click',function(){
		$('#span_PageNum').text(++comparisonQuery.page)	
		drawComparisonTable();
	});

	$('#btn_exportCSV').on('click',function(){
		var csv = $('#div_combinedResultsVisualization table').table2CSV({
			delivery: 'value'
		});
		var vendorName = window.navigator.vendor;
		if(vendorName == "Google Inc.") {
		   // is Google chrome 
			window.location.href = 'data:text/csv;charset=UTF-8,' + encodeURIComponent(csv);
		}
		else{
			alert("-----Use Google Chrome to save file to disk.-----\n\n" + csv);
		}
	});
}

//Apply functions to various elements
function apply_functions(side, collection){

	//Create jquery UI comboboxes
	$('#div_' + side + 'RefineControls select').combobox({
		select: function(event, ui) {
			var id = event.target.id;
			if(id == "sel_" + side + "Predicate")
				updateValueSelector(this.value,"sel_"+ side + "PredicateValue", collection);
		}
	});

	$('#btn_' + side + 'ShowChart').on('click',function(){
		hardLimit=2000;
		drawFilteredDataset(side, collection);
	});

	$('#btn_' + side + 'ShowQuery').on('click',function(){
		hardLimit=2000;
		alert(generateQuery(side,collection));	
	});

	$('#btn_' + side + 'SubmitQuery').on('click',function(){
		paper.install(window);
		var color = updateCircle(side);
		comparisonQuery = new ComparisonQuery();
		$('#div_' + side + 'Indicator').css("background-color",color); 
	});

	//When a <tr> in overview table is selected, select in predicate dropdown
	$('#div_' + side + 'Overview.overview tr').live("click", function(){
		var clickedText = tidyPredicate($(this).children(":first").text());
		$('#sel_' + side + 'Predicate option[text="' + clickedText + '"]').attr('selected','selected');
		$('#sel_' + side + 'Predicate option').filter(function(){
			return $(this).text() == clickedText;
		}).attr('selected', true);
		
		$('#sel_' + side + 'Predicate').siblings('.custom-combobox').find('.custom-combobox-input').val(clickedText);
		updateValueSelector($('#sel_' + side + 'Predicate option:selected').val(),"sel_"+ side + "PredicateValue", collection);

		if($('#cb_quickSearch').is(':checked'))	{	
			hardLimit=500;
			drawFilteredDataset(side, collection);
		}
		
		//When TD is selected, highlight similar TD's in opposite table
		showSimilarPredicates(side,$(this).children(":first").text());
	});

	$('#cb_' + side + 'RefineSearch').on('click', function(){
		$('#table_' + side + 'RefineControls').toggle();	
	});

	$('#sel_' + side + 'Collection').on('change',function(){
		if(side=="left")
			leftCollection = $('#sel_' + side + 'Collection').val();
		else
			rightCollection = $('#sel_' + side + 'Collection').val();

		drawSide(side, $('#sel_' + side + 'Collection').val());
	});
}
function showSimilarPredicates(side,clickedText){

	var oppositeSide;
	if(side == "left")
		oppositeSide = "right";
	else
		oppositeSide = "left";
		
	$('#div_' + oppositeSide + 'Overview.overview tr').each(function(){
		if($(this).children(":first").text() == clickedText)
			$(this).children(":first").addClass("bold");
		else
			$(this).children(":first").removeClass("bold");

	});
		
	$('#div_' + side + 'Overview.overview tr').each(function(){
		if($(this).children(":first").text() == clickedText)
			$(this).children(":first").addClass("bold");
		else
			$(this).children(":first").removeClass("bold");
	});
}
